@@ -1,7 +1,7 @@
 /* Common interrupt GUI handlers for xview, motif, etc. */
 
 /*
- * Copyright (c) 1995  En Garde Systems. All rights reserved.
+ * Copyright (c) 2000  En Garde Systems. All rights reserved.
  *    
  * Redistribution and use in source and binary forms, with or without    
  * modification, for NON COMMERCIAL USE are permitted provided that: 
@@ -16,8 +16,8 @@
  * 
  * For commercial use or modification of this program, contact:
  * En Garde Systems
- * 525 Clara Avenue, Suite 202
- * St. Louis, MO  63112
+ * 4848 Tramway Ridge, Suite 122
+ * Albuquerque, NM 87111
  */
 
 #include <stdio.h>
@@ -37,7 +37,15 @@
 #include <malloc.h>
 #include <sys/stream.h>
 #include <stropts.h>
-#include <utmp.h>
+#ifdef SOLARIS
+# include <utmpx.h>
+# define UTMP_PATH UTMPX_FILE
+# define utmp utmpx
+# define ut_time ut_tv.tv_sec
+#else
+# include <utmp.h>
+# define UTMP_PATH "/etc/utmp"
+#endif
 #include <pwd.h>
 
 #ifdef SOLARIS
@@ -52,13 +60,13 @@ extern time_t gtime;
 extern struct con *current, *con_hash[];
 extern u_long lastack;
 extern struct con *row_list;
-extern int active, lastsaveddatalen, reachedEOF;
+extern int reachedEOF;
 extern int playspeed, paused;
 int cspos=0;
 int purge_time=120;
 int watched_rawlog=0;
 
-static char *RCSid="$Id: common.c,v 1.3 1995/06/14 19:35:21 mcn Exp $";
+static char *RCSid="$Id: common.c,v 1.8 2000/03/03 17:10:50 mcn Exp $";
 
 static char RAW_MAGIC[] = { 'W','a','t','c','h','e','r','R','a','w','1','.','0' };
 
@@ -105,7 +113,6 @@ if (value==1) {
 			set_fi_value(rawlog_filename, 1);
    			return;
     	} else {
-   			lastsaveddatalen=-1;
    			buf=(char *)get_filename2();
    			if ((raw_log=open(buf, O_WRONLY|O_CREAT|O_EXCL, 0600))<0) {
             	perror("open raw");
@@ -259,13 +266,10 @@ int row;
     	}
 	}
 	sprintf(buf,"%-34s  %5d",  cp->name, cp->bytes_sent);
-	if (xv) {
+	if (xv)
 		add_row(buf, (int)cp, row);
-		active++;
-	} else {
+	else
 		curses_insert_row(buf, cp);
-		active++;
-	}
 
 	com_put_in_active(cp->next);
 	return;
@@ -292,7 +296,7 @@ char rawbuf[80];
 if (!value && !current_input) return; /* choose file, already rdng from there */
 if (value && current_input)   return; /* choose net, already rdng from there */
 if (current_input) {  /* Reading from network */
-  strncpy(fbuf, get_filename(), 120);
+  strncpy(fbuf, (char *)get_filename(), 120);
   if (!strlen(fbuf) || access(fbuf, R_OK)) {
 	if (!strlen(fbuf)) {
 		strcpy(fbuf, "Must Enter a filename"); 
@@ -344,9 +348,7 @@ if (mapped)  {
 	current=NULL;
 }
 set_error_label("");
-active=0;
 if (current_input)  { /* reading from system */
-    lastsaveddatalen=-1;
     watched_rawlog=1;
     current_input=0;
 	show_hosebutton(0);
@@ -359,6 +361,7 @@ if (current_input)  { /* reading from system */
 } else {
     current_input=1;
 	show_hosebutton(1);
+	time(&gtime);
 }
 }
 
@@ -621,89 +624,127 @@ return;
 }
 
 struct utmp_list {
-	struct utmp *data;
-	struct utmp_list *next;
-	struct utmp_list *prev;
+  struct utmp *data;
+  int checked;            /* Set to 1 if this tty is verified by check_utmp */
+  struct utmp_list *next;
+  struct utmp_list *prev;
 } *Master_utmp=NULL;
 
 /* This stats /etc/utmp (/etc/utmpx eventually) and checks to see if it
- * has been modified. If so, it compares it's stored version with the one
+ * has been modified. If so, it compares its stored version with the one
  * in utmp to see if anyone has logged in. If they have, push TAP onto their
  * stream, and send a SYN?
  */
 com_check_utmp()
 {
-static time_t last_change=0;
-struct stat sb;
-int fd;
-struct utmp ut;
-struct utmp_list *ul, *tul;
-int c;
+  static time_t last_change=0;
+  struct stat sb;
+  int fd;
+  struct utmp ut;
+  struct utmp_list *ul, *tul;
+  int c, p;
+  
+  if (stat(UTMP_PATH, &sb)<0) return; /* Oh well? */
+  if (sb.st_mtime==last_change) return; /* Nothing to do! */
+  /* 
+   * We've short circuited all the obvious possibilities. Now we need to
+   * actually do something... 
+   */
+  last_change=sb.st_mtime;
+  if ((fd=open(UTMP_PATH, O_RDONLY))<0) 
+    return; /* Oh well again... */
 
-if (stat("/etc/utmp", &sb)<0) return; /* Oh well? */
-if (sb.st_mtime==last_change) return; /* Nothing to do! */
-/* 
- * We've short circuited all the obvious possibilities. Now we need to
- * actually do something... 
- */
-last_change=sb.st_mtime;
-if ((fd=open("/etc/utmp", O_RDONLY))<0) return; /* Oh well again... */
-while (read(fd, &ut, sizeof(struct utmp))==sizeof(struct utmp)) {
-	if (ut.ut_name[0]=='\0' || ut.ut_line[0]=='\0') continue; /*Blank entry*/
-	ul=Master_utmp;
-	if (ul==NULL) {
-		Master_utmp=(struct utmp_list *)malloc(sizeof(struct utmp_list));
-		ul=Master_utmp;
-		ul->prev=NULL;
-		ul->next=NULL;
-		ul->data=(struct utmp *)malloc(sizeof(struct utmp));
-		memcpy(ul->data, &ut, sizeof(struct utmp));
-		push_twtch(ut.ut_line);
-		continue;
+  for (ul=Master_utmp;ul!=NULL;ul=ul->next)
+    ul->checked = 0; /* Initialize all of them to not checked */
+
+  while (read(fd, &ut, sizeof(struct utmp))==sizeof(struct utmp)) {
+    if (ut.ut_name[0]==0 || ut.ut_line[0]==0
+#ifdef SOLARIS
+	|| ut.ut_type != USER_PROCESS
+#endif
+	) continue; /*Blank entry*/
+
+    /* Make sure it's actually being used by a process */
+    if ((p = open(ut.ut_line, O_RDWR | O_NOCTTY)) >= 0) {
+      /* This one isn't used! */
+      close(p);
+      continue;
+    }
+    for (ul=Master_utmp;ul!=NULL;ul=ul->next) {
+      /* Try to find the TTY */
+      if (strncmp(ul->data->ut_line, ut.ut_line, 8)==0) break;
+    }
+    if (ul) {
+      if (ul->data->ut_time!=ut.ut_time ||
+	  strncmp(ul->data->ut_name, ut.ut_name, 8) != 0) {
+	/* User or last login time has changed */
+
+	memcpy(ul->data, &ut, sizeof(struct utmp)); /* Update our records */
+	push_twtch(ut.ut_line);                     /* push twtch */
+      }
+      ul->checked = 1;
+    } else {
+      /* We have a new login! */
+      ul = (struct utmp_list *)malloc(sizeof(struct utmp_list));
+      ul->checked = 1;
+      ul->prev = NULL;
+      ul->next = NULL;
+      ul->data = (struct utmp *)malloc(sizeof(struct utmp));
+      memcpy(ul->data, &ut, sizeof(struct utmp));
+
+      /* Now, insert ul into the list */
+
+      /* Case 1: There are no entries in the list */
+      if (Master_utmp == NULL) {
+	Master_utmp = ul;
+      } else {
+	/* Find the entry */
+	for (tul = Master_utmp; 
+	     tul->next!=NULL && strncmp(tul->data->ut_line, ut.ut_line, 8) < 0;
+	     tul = tul->next) ;
+
+	if (strncmp(tul->data->ut_line, ut.ut_line, 8)>=0) {
+	  /* Case 2: Insert before this one */
+	  if (tul->prev != NULL) 
+	    tul->prev->next = ul;
+	  ul->prev = tul->prev;
+	  ul->next = tul; 
+	  tul->prev = ul; 
+	  if (ul->prev == NULL) /* First entry */ 
+	    Master_utmp = ul;
 	} else {
-		c=1;
-		while (ul->next!=NULL && (c=strncmp(ul->data->ut_line, ut.ut_line, 8))<0) 
-			ul=ul->next; /* Find the tty */
-		if (c == 0) { /* found it */
-			if (ut.ut_name[0]=='\0') {
-				ul->data->ut_time=0; /* offline */
-				ul->data->ut_name[0]='\0';
-			} else
-			if (strncmp(ut.ut_name, ul->data->ut_name, 8) == 0) {
-				if (ul->data->ut_time!=ut.ut_time) 
-					push_twtch(ut.ut_line);
-				ul->data->ut_time=ut.ut_time; /* Same person */
-			} else {
-				strncpy(ul->data->ut_name, ut.ut_name, 8);
-				ul->data->ut_time=ut.ut_time;
-				/* New user, push twtch on their stream */
-				push_twtch(ut.ut_line);
-			}
-		} else { /* New tty in utmp */
-			/* We're at the last entry of the list */
-			tul=(struct utmp_list *)malloc(sizeof(struct utmp_list));
-			tul->data=(struct utmp *)malloc(sizeof(struct utmp));
-			memcpy(tul->data, &ut, sizeof(struct utmp));
-			if (ul->next==NULL) { /* Insert at the end */
-				tul->next=ul->next;
-				tul->prev=ul;
-				if (tul->next)
-					tul->next->prev=tul;
-				ul->next=tul;
-			} else { /* Insert before this one */
-				tul->next=ul;
-				tul->prev=ul->prev;
-				if (tul->prev)
-					tul->prev->next=tul;
-				ul->prev=tul;
-			}
-			if (ut.ut_name[0]!='\0') 
-				push_twtch(ut.ut_line);
-		}
+	  /* Case 3: Insert at the end of the list */
+	  tul->next = ul;
+	  ul->next = NULL;
+	  ul->prev = tul;
 	}
-}
-close(fd);
-return;
+      }
+      push_twtch(ut.ut_line);
+    }
+  }
+  close(fd);
+
+  /* Now, go through the Master_utmp list and weed out all the dead ttys */
+  ul=Master_utmp;
+  while (ul!=NULL) {
+    if (ul->checked==0) {
+
+      if (ul->prev == NULL) {
+	Master_utmp = ul->next;
+	ul->next->prev = NULL;
+      } else {
+	ul->prev->next = ul->next;
+	if (ul->next != NULL)
+	  ul->next->prev = ul->prev;
+      }
+      tul = ul;
+      ul = ul->next;
+      free(tul);
+    } else {
+      ul = ul->next;
+    }
+  }
+  return;
 }
 
 push_twtch(dev)
