@@ -1,7 +1,7 @@
 /* File Descriptor and initialization for TTY-Watcher */
 
 /*
- * Copyright (c) 1995  En Garde Systems. All rights reserved.
+ * Copyright (c) 2000  En Garde Systems. All rights reserved.
  *    
  * Redistribution and use in source and binary forms, with or without    
  * modification, for NON COMMERCIAL USE are permitted provided that: 
@@ -16,8 +16,8 @@
  * 
  * For commercial use or modification of this program, contact:
  * En Garde Systems
- * 525 Clara Avenue, Suite 202
- * St. Louis, MO  63112
+ * 4848 Tramway Ridge, Suite 122
+ * Albuquerque, NM 87111
  */
 
 
@@ -28,21 +28,23 @@
 #include <sys/time.h>
 #include <time.h>
 
-extern time_t pkt_time;
+static char *RCSid="$Id: init.c,v 1.3 2000/03/03 17:10:51 mcn Exp $";
 
-int twtchfd;
-
-static char *RCSid="$Id: init.c,v 1.1.1.1 1995/06/12 17:38:19 mcn Exp $";
 
 int init()
 {
+extern time_t pkt_time;
+
 pkt_time=0;
 
 open_twtch();
 com_check_utmp();
-return(0); /* Fix this so it initializes the streams modules et al. */
+return(0);
 }
 
+
+int twtchfd;
+
 open_twtch()
 {
 	if ((twtchfd=open("/dev/twtchc", O_RDWR|O_NDELAY))<0) {
