@@ -1,7 +1,7 @@
 /* XView GUI interface for TTY-Watcher */
 
 /*
- * Copyright (c) 1995  En Garde Systems. All rights reserved.
+ * Copyright (c) 2000  En Garde Systems. All rights reserved.
  *    
  * Redistribution and use in source and binary forms, with or without    
  * modification, for NON COMMERCIAL USE are permitted provided that: 
@@ -16,8 +16,8 @@
  * 
  * For commercial use or modification of this program, contact:
  * En Garde Systems
- * 525 Clara Avenue, Suite 202
- * St. Louis, MO  63112
+ * 4848 Tramway Ridge, Suite 122
+ * Albuquerque, NM 87111
  */
 
 
@@ -37,7 +37,7 @@
 
 #include "ses_packet.h"
 
-static char *RCSid="$Id: xview.c,v 1.3 1995/06/14 19:48:00 mcn Exp $";
+static char *RCSid="$Id: xview.c,v 1.9 2000/03/28 16:33:34 mcn Exp $";
 
 Frame frame;
 Xv_Font font;
@@ -55,14 +55,29 @@ Panel panel_tty, panel_tty2;
 Panel_item lc_item, fi_item, fi2_item, ra_item, climess_item;
 Panel_item mess_item4, ts_item;
 
-void hose(), pause_playback();
-void FF_playback(), sendrst(), climessage(), tty_popdown(), tty_status();
-
 extern struct con *current;
 extern int mapped, ttyfd, current_mode, current_input;
 
 static int login_windows_created=0, been_created=0;
 
+/* Declare the functions used below */
+void log_current(), set_fi_value(), set_ra_value(), set_lc_value();
+void ss_choice(), choose_input(), set_error_label(), set_input_item();
+void create_login_windows(), quit(), kill_frame(), textcs_erase();
+void textcs_reset(), textsc_insert(), pause_playback(), FF_playback();
+void create_windows(), update_windows(), set_ct_time_label();
+void set_ct_date_label(), set_lt_time_label(), set_lt_date_label();
+void set_issyn_label(), erase_issyn_label(), textcs_insert();
+void textcs_reposition(), hose(), tty_popdown(), sendrst(), climessage();
+void delete_row(), set_status_label(), add_row(), delete_all_rows();
+void select_row(), reset_mapping(), set_row_label(), set_row_title();
+void show_hosebutton(), tty_status();
+char *get_filename(), *get_filename2(), *get_climss_str();
+int which_choice();
+Notify_func timer_update();
+/* End of declarations */
+
+
 void log_current(item, value, event)
 Panel_item item;
 int value;
@@ -72,7 +87,7 @@ com_log_current(value);
 return;
 }
 
-set_fi_value(label, active) 
+void set_fi_value(label, active) 
 char *label;
 int active;
 {
@@ -81,13 +96,13 @@ xv_set(fi2_item, PANEL_VALUE, label,
 		NULL);
 }
 
-set_ra_value(value)
+void set_ra_value(value)
 int value;
 {
 xv_set(ra_item, PANEL_VALUE, value, NULL);
 }
 
-set_lc_value(value)
+void set_lc_value(value)
 int value;
 {
 xv_set(lc_item, PANEL_VALUE, value, NULL);
@@ -122,13 +137,13 @@ char *get_filename2()
 return((char *)xv_get(fi2_item, PANEL_VALUE));
 }
 
-set_error_label(label)
+void set_error_label(label)
 char *label;
 {
 xv_set(error_item, PANEL_LABEL_STRING, label, NULL);
 }
 
-set_input_item(value)
+void set_input_item(value)
 int value;
 {
 xv_set(input_item, PANEL_VALUE, value, NULL);
@@ -159,9 +174,9 @@ if (op==PANEL_LIST_OP_DESELECT) {
 else 
 	return(XV_ERROR);
 return(XV_OK);
-};
+}
 
-create_login_windows()
+void create_login_windows()
 {
   int  nonblock;
   char buf[80];
@@ -412,7 +427,7 @@ Event *event;
 com_quit();
 }
 
-kill_frame()
+void kill_frame()
 {
 if (mapped)
    reset_mapping(); /* Hopefully this will fix the utmp entry */
@@ -422,19 +437,19 @@ xv_destroy_immediate(frame_tty);
 xv_destroy_immediate(frame);
 }
 
-textcs_erase(start,fin)
+void textcs_erase(start,fin)
 int start,fin;
 {
 if (fin==-1) fin = TEXTSW_INFINITY;
 textsw_erase(textcs, start, fin);
 }
 
-textcs_reset()
+void textcs_reset()
 {
 textsw_reset(textcs, 0, 0);
 }
 
-textsc_insert(buf, x)
+void textsc_insert(buf, x)
 char *buf;
 int x;
 {
@@ -461,14 +476,13 @@ com_FF_playback();
 }
 
 
-Display *dpy;
+static Display *dpy;
 
-create_windows(argc, argv)
+void create_windows(argc, argv)
 int argc;
 char *argv[];
 {
 struct itimerval itimer;
-void timer_update();
 
     xv_init(XV_INIT_ARGC_PTR_ARGV, &argc, argv, NULL);
 
@@ -560,37 +574,37 @@ void timer_update();
 	notify_set_itimer_func(frame, timer_update, ITIMER_REAL, &itimer, NULL);
 }
 
-update_windows()
+void update_windows()
 {
 	notify_dispatch();
 	XFlush(dpy);
 }
 
-set_ct_time_label(label)
+void set_ct_time_label(label)
 char *label;
 {
 xv_set(mess_item2, PANEL_LABEL_STRING, label, NULL);
 }
 
-set_ct_date_label(label)
+void set_ct_date_label(label)
 char *label;
 {
 xv_set(mess_item2_5, PANEL_LABEL_STRING, label, NULL);
 }
 
-set_lt_time_label(label)
+void set_lt_time_label(label)
 char *label;
 {
 xv_set(mess_item3, PANEL_LABEL_STRING, label, NULL);
 }
 
-set_lt_date_label(label)
+void set_lt_date_label(label)
 char *label;
 {
 xv_set(mess_item3_5, PANEL_LABEL_STRING, label, NULL);
 }
 
-set_issyn_label(label)
+void set_issyn_label(label)
 char *label;
 {
 xv_set(mess_item, 
@@ -598,14 +612,14 @@ xv_set(mess_item,
 	NULL);
 }
 
-erase_issyn_label()
+void erase_issyn_label()
 {
 xv_set(mess_item, 
 	PANEL_LABEL_STRING, "                                              ",
 	NULL);
 }
 
-textcs_insert(buf, len)
+void textcs_insert(buf, len)
 char *buf;
 int len;
 {
@@ -613,7 +627,7 @@ textsw_insert(textcs, buf, len);
 textsw_possibly_normalize(textcs, 1);
 }
 
-textcs_reposition()
+void textcs_reposition()
 {
 xv_set(textcs, TEXTSW_FIRST, 1, NULL);
 }
@@ -660,13 +674,13 @@ char *get_climess_str()
 return((char *)xv_get(climess_item, PANEL_VALUE));
 }
 
-delete_row(row)
+void delete_row(row)
 int row;
 {
 xv_set(panel_item, PANEL_LIST_DELETE, row, NULL); 
 }
 
-set_status_label(label, color)
+void set_status_label(label, color)
 char *label, *color;
 {
 int numcolor=BLACK;
@@ -681,7 +695,7 @@ xv_set(mess_item4, PANEL_LABEL_STRING, label,
 		NULL);
 }
 
-add_row(label, data, row)
+void add_row(label, data, row)
 char *label;
 int data;
 int row;
@@ -691,14 +705,14 @@ xv_set(panel_item, PANEL_LIST_INSERT, row,
 		PANEL_LIST_CLIENT_DATA, row, data, NULL);
 }
 
-delete_all_rows()
+void delete_all_rows()
 {
 int i=(int)xv_get(panel_item, PANEL_LIST_NROWS);
 
 xv_set(panel_item, PANEL_LIST_DELETE_ROWS, 0, i, NULL);
 }
 
-select_row(rownum)
+void select_row(rownum)
 int rownum;
 {
 int first_selected=(int)xv_get(panel_item, PANEL_LIST_FIRST_SELECTED);
@@ -709,12 +723,12 @@ if (rownum>=0)
   xv_set(panel_item, PANEL_LIST_SELECT, rownum, TRUE, NULL);
 }
 
-reset_mapping()
+void reset_mapping()
 {
 xv_set(frame_tty, FRAME_CMD_PIN_STATE, FRAME_CMD_PIN_OUT, XV_SHOW, FALSE, NULL);
 }
 
-set_row_label(row, label, data)
+void set_row_label(row, label, data)
 int row, data;
 char *label;
 {
@@ -723,14 +737,14 @@ xv_set(panel_item, PANEL_LIST_STRING, row, label,
 	NULL);
 }
 
-set_row_title(row, label)
+void set_row_title(row, label)
 int row;
 char *label;
 {
 xv_set(panel_item, PANEL_LIST_STRING, row, label, NULL);
 }
 
-show_hosebutton(value)
+void show_hosebutton(value)
 int value;
 {
 xv_set(hose_button, XV_SHOW, value, NULL);
@@ -751,7 +765,7 @@ else
 current->ttystatus=value;
 }
 
-void timer_update(client, which)
+Notify_func timer_update(client, which)
 /* This routine should be called every second */
 Notify_client client;
 int which;
@@ -761,7 +775,11 @@ extern int erase_issyn;
 static int ticks=0;
 
 if (current_input)
-	(void)time(&gtime);
+	gtime++; 
+	/* 
+	 * Increment gtime every "second". It may not be accurate, but it's
+	 * good enough for displaying something on the screen 
+	 */
 ticks++;
 if (ticks & 4) { /* Every 4 seconds */
 	ticks=0;
@@ -773,5 +791,5 @@ if (erase_issyn>0) {
 	erase_issyn=0;
 } else
 	erase_issyn+=60; /* This should be 5 seconds */
-return;
+return(NOTIFY_DONE);
 }
